summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorMattias Andrée <maandree@operamail.com>2014-02-24 11:39:52 +0100
committerMattias Andrée <maandree@operamail.com>2014-02-24 11:39:52 +0100
commit6bd6132aaa066a3a1aea47d9fabec28651a0c003 (patch)
treece964aa2224e415fd3b8fbfcb2517dff772d0847 /src
parenttypo (diff)
downloadblueshift-6bd6132aaa066a3a1aea47d9fabec28651a0c003.tar.gz
blueshift-6bd6132aaa066a3a1aea47d9fabec28651a0c003.tar.bz2
blueshift-6bd6132aaa066a3a1aea47d9fabec28651a0c003.tar.xz
m doc
Signed-off-by: Mattias Andrée <maandree@operamail.com>
Diffstat (limited to 'src')
-rw-r--r--src/blueshift_randr_c.c20
-rw-r--r--src/monitor.py8
2 files changed, 14 insertions, 14 deletions
diff --git a/src/monitor.py b/src/monitor.py
index 4a7c1f8..71343a4 100644
--- a/src/monitor.py
+++ b/src/monitor.py
@@ -64,7 +64,7 @@ def close_c_bindings():
def randr_get(crtc = 0, screen = 0):
'''
- Gets the current colour curves using the X11 extension randr
+ Gets the current colour curves using the X11 extension RandR
@param crtc:int The CRTC of the monitor to read from
@param screen:int The screen that the monitor belong to
@@ -94,7 +94,7 @@ def randr_get(crtc = 0, screen = 0):
def vidmode_get(crtc = 0, screen = 0):
'''
- Gets the current colour curves using the X11 extension vidmode
+ Gets the current colour curves using the X11 extension VidMode
@param crtc:int The CRTC of the monitor to read from
@param screen:int The screen that the monitor belong to
@@ -124,7 +124,7 @@ def vidmode_get(crtc = 0, screen = 0):
def randr(*crtcs, screen = 0):
'''
- Applies colour curves using the X11 extension randr
+ Applies colour curves using the X11 extension RandR
@param crtcs:*int The CRT controllers to use, all are used if none are specified
@param screen:int The screen that the monitors belong to
@@ -152,7 +152,7 @@ def randr(*crtcs, screen = 0):
def vidmode(*crtcs, screen = 0):
'''
- Applies colour curves using the X11 extension vidmode
+ Applies colour curves using the X11 extension VidMode
@param crtcs:*int The CRT controllers to use, all are used if none are specified
@param screen:int The screen that the monitors belong to
diff --git a/src/blueshift_randr_c.c b/src/blueshift_randr_c.c
index d7be886..e160052 100644
--- a/src/blueshift_randr_c.c
+++ b/src/blueshift_randr_c.c
@@ -24,12 +24,12 @@
/**
* The major version of RANDR the program expects
*/
#define RANDR_VERSION_MAJOR 1U
/**
* The minor version of RANDR the program expects
*/
#define RANDR_VERSION_MINOR 3U
@@ -110,21 +110,21 @@ int blueshift_randr_open(int use_screen)
connection = xcb_connect(NULL, &use_screen);
/* Check RANDR protocol version */
version_cookie = xcb_randr_query_version(connection, RANDR_VERSION_MAJOR, RANDR_VERSION_MINOR);
randr_version = xcb_randr_query_version_reply(connection, version_cookie, &error);
if (error || (randr_version == NULL))
{
- fprintf(stderr, "RANDR version query returned %i", error ? error->error_code : -1);
+ fprintf(stderr, "RandR version query returned %i", error ? error->error_code : -1);
xcb_disconnect(connection);
return 1;
}
if (randr_version->major_version != RANDR_VERSION_MAJOR || randr_version->minor_version < RANDR_VERSION_MINOR)
{
- fprintf(stderr, "Unsupported RANDR version, got %u.%u, expected %u.%u\n",
+ fprintf(stderr, "Unsupported RandR version, got %u.%u, expected %u.%u\n",
randr_version->major_version, randr_version->minor_version,
RANDR_VERSION_MAJOR, RANDR_VERSION_MINOR);
free(randr_version);
@@ -146,7 +146,7 @@ int blueshift_randr_open(int use_screen)
if (error)
{
- fprintf(stderr, "RANDR screen resource query returned %i\n", error->error_code);
+ fprintf(stderr, "RandR screen resource query returned %i\n", error->error_code);
xcb_disconnect(connection);
return 1;
}
@@ -177,7 +177,7 @@ int blueshift_randr_open(int use_screen)
if (error)
{
- fprintf(stderr, "RANDR CRTC gamma size query returned %i\n", error->error_code);
+ fprintf(stderr, "RandR CRTC gamma size query returned %i\n", error->error_code);
xcb_disconnect(connection);
return 1;
}
@@ -193,7 +193,7 @@ int blueshift_randr_open(int use_screen)
if (error)
{
- fprintf(stderr, "RANDR CRTC gamma query returned %i\n", error->error_code);
+ fprintf(stderr, "RandR CRTC gamma query returned %i\n", error->error_code);
xcb_disconnect(connection);
return 1;
}
@@ -230,7 +230,7 @@ uint16_t* blueshift_randr_read(int use_crtc)
if (error)
{
- fprintf(stderr, "RANDR CRTC gamma query returned %i\n", error->error_code);
+ fprintf(stderr, "RandR CRTC gamma query returned %i\n", error->error_code);
xcb_disconnect(connection);
return NULL;
}
@@ -301,7 +301,7 @@ int blueshift_randr_apply(uint64_t use_crtcs, uint16_t* r_curve, uint16_t* g_cur
if (error)
{
- fprintf(stderr, "RANDR CRTC control returned %i\n", error->error_code);
+ fprintf(stderr, "RandR CRTC control returned %i\n", error->error_code);
return 1;
}
@@ -24,12 +24,12 @@
/**
- * The major version of RANDR the program expects
+ * The major version of RandR the program expects
*/
#define RANDR_VERSION_MAJOR 1U
@@ -24,12 +24,12 @@
#define RANDR_VERSION_MAJOR 1U
/**
- * The minor version of RANDR the program expects
+ * The minor version of RandR the program expects
*/
#define RANDR_VERSION_MINOR 3U
@@ -110,21 +110,21 @@ int blueshift_randr_open(int use_screen)
connection = xcb_connect(NULL, &use_screen);
- /* Check RANDR protocol version */
+ /* Check RandR protocol version */
version_cookie = xcb_randr_query_version(connection, RANDR_VERSION_MAJOR, RANDR_VERSION_MINOR);
randr_version = xcb_randr_query_version_reply(connection, version_cookie, &error);